@@ -21,12 +21,12 @@ Create Date: 2016-08-05 15:31:46.203266
 revision = 'b1f612248cab'
 down_revision = '859fb45df249'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+import sqlalchemy as sa  # noqa: E402
 
 
 def upgrade():
     op.add_column('baymodel',
                   sa.Column('floating_ip_enabled',
-                            sa.Boolean(),
+                            sa.Boolean(create_constraint=False),
                             default=True))
