@@ -21,14 +21,17 @@ Create Date: 2016-08-22 15:04:32.256811
 revision = 'fcb4efee8f8b'
 down_revision = 'b1f612248cab'
 
-from alembic import op
-import sqlalchemy as sa
+from alembic import op  # noqa: E402
+
+from sqlalchemy.types import String  # noqa: E402
+
+import sqlalchemy as sa  # noqa: E402
 
 
 def upgrade():
     op.add_column('bay',
-                  sa.Column('coe_version', sa.String(length=255),
+                  sa.Column('coe_version', String(255),
                             nullable=True))
     op.add_column('bay',
-                  sa.Column('container_version', sa.String(length=255),
+                  sa.Column('container_version', String(255),
                             nullable=True))
