@@ -21,7 +21,14 @@ from magnum.tests.unit.api import utils as api_utils
 from magnum.tests.unit.objects import utils as obj_utils
 
 
-HEADERS = {'OpenStack-API-Version': 'container-infra latest'}
+READER_HEADERS = {
+    'OpenStack-API-Version': 'container-infra latest',
+    "X-Roles": "reader"
+}
+HEADERS = {
+    'OpenStack-API-Version': 'container-infra latest',
+    "X-Roles": "member"
+}
 
 
 class TestCertObject(base.TestCase):
@@ -59,11 +66,9 @@ class TestGetCaCertificate(api_base.FunctionalTest):
         self.conductor_api.get_ca_certificate.return_value = mock_cert
 
         response = self.get_json('/certificates/%s' % self.cluster.uuid,
-                                 headers=HEADERS)
+                                 headers=READER_HEADERS)
 
         self.assertEqual(self.cluster.uuid, response['cluster_uuid'])
-        # check that bay is still valid as well
-        self.assertEqual(self.cluster.uuid, response['bay_uuid'])
         self.assertEqual(fake_cert['csr'], response['csr'])
         self.assertEqual(fake_cert['pem'], response['pem'])
 
@@ -74,17 +79,16 @@ class TestGetCaCertificate(api_base.FunctionalTest):
         self.conductor_api.get_ca_certificate.return_value = mock_cert
 
         response = self.get_json('/certificates/%s' % self.cluster.name,
-                                 headers=HEADERS)
+                                 headers=READER_HEADERS)
 
         self.assertEqual(self.cluster.uuid, response['cluster_uuid'])
-        # check that bay is still valid as well
-        self.assertEqual(self.cluster.uuid, response['bay_uuid'])
         self.assertEqual(fake_cert['csr'], response['csr'])
         self.assertEqual(fake_cert['pem'], response['pem'])
 
     def test_get_one_by_name_not_found(self):
         response = self.get_json('/certificates/not_found',
-                                 expect_errors=True, headers=HEADERS)
+                                 expect_errors=True,
+                                 headers=READER_HEADERS)
 
         self.assertEqual(404, response.status_int)
         self.assertEqual('application/json', response.content_type)
@@ -97,7 +101,8 @@ class TestGetCaCertificate(api_base.FunctionalTest):
                                       uuid=uuidutils.generate_uuid())
 
         response = self.get_json('/certificates/test_cluster',
-                                 expect_errors=True, headers=HEADERS)
+                                 expect_errors=True,
+                                 headers=READER_HEADERS)
 
         self.assertEqual(409, response.status_int)
         self.assertEqual('application/json', response.content_type)
@@ -110,7 +115,7 @@ class TestGetCaCertificate(api_base.FunctionalTest):
         self.conductor_api.get_ca_certificate.return_value = mock_cert
 
         response = self.get_json('/certificates/%s' % self.cluster.uuid,
-                                 headers=HEADERS)
+                                 headers=READER_HEADERS)
 
         self.assertIn('links', response.keys())
         self.assertEqual(2, len(response['links']))
@@ -149,23 +154,6 @@ class TestPost(api_base.FunctionalTest):
         self.assertEqual(201, response.status_int)
         self.assertEqual(new_cert['cluster_uuid'],
                          response.json['cluster_uuid'])
-        # verify bay_uuid is still valid as well
-        self.assertEqual(new_cert['cluster_uuid'], response.json['bay_uuid'])
-        self.assertEqual('fake-pem', response.json['pem'])
-
-    # Test that bay_uuid is still backward compatible
-    def test_create_cert_by_bay_name(self, ):
-        new_cert = api_utils.cert_post_data(cluster_uuid=self.cluster.uuid)
-        del new_cert['pem']
-        new_cert['bay_uuid'] = new_cert['cluster_uuid']
-        del new_cert['cluster_uuid']
-
-        response = self.post_json('/certificates', new_cert, headers=HEADERS)
-        self.assertEqual('application/json', response.content_type)
-        self.assertEqual(201, response.status_int)
-        self.assertEqual(self.cluster.uuid, response.json['cluster_uuid'])
-        # verify bay_uuid is still valid as well
-        self.assertEqual(self.cluster.uuid, response.json['bay_uuid'])
         self.assertEqual('fake-pem', response.json['pem'])
 
     def test_create_cert_by_cluster_name(self, ):
@@ -265,7 +253,7 @@ class TestCertPolicyEnforcement(api_base.FunctionalTest):
         self._common_policy_check(
             "certificate:get", self.get_json,
             '/certificates/%s' % cluster.uuid,
-            expect_errors=True, headers=HEADERS)
+            expect_errors=True, headers=READER_HEADERS)
 
     def test_policy_disallow_create(self):
         cluster = obj_utils.create_test_cluster(self.context)
